#!perl -T
use 5.12.0;
use strict;
use warnings FATAL => 'all';
use Test::More;

plan skip_all => 'these tests are for authors only!' unless ( $ENV{AUTHOR_TESTING} ||  $ENV{RELEASE_TESTING} );
eval 'use Test::CPAN::Changes';
plan skip_all => 'Test::CPAN::Changes required for this test' if $@;

changes_ok( );
